#!/usr/bin/perl

# video.cgi:
# Lightweight video-logging CGI script.
#
# Copyright (c) 2006-2007 Daniel Jones. All rights reserved.
# <http://www.erase.net/>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You may have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
#

use strict;
use warnings;
use Template;
use CGI;
use Template::Stash;

my $linkfile = "/home/user/blog.video";
my $pwd = $ENV{SCRIPT_FILENAME};
$pwd =~ s,[^/]+$,,;

my @clips = getclips($linkfile);

# init vmethods
$Template::Stash::SCALAR_OPS->{ uc } = sub { uc shift };

my $t = new Template(ABSOLUTE => 1);
my $q = new CGI;

my $v = $q->param("v");
$v = $#clips unless defined $v;

my $clip = $clips[$v] or die;
my $html;

$t->process("$pwd/template.tt2", { clip => $clip }, \$html)
	or die $t->error;

print "Content-type: text/html\n\n";
print $html;

sub	getclips
{
	my ($file) = @_;

	open (my $fd, $file);
	my @lines = grep { /\S/ } <$fd>;
	chomp @lines;

	my @clips;

	for (@lines)
	{
		my ($expired, $code, $title) = (/^(#\s*)?(\S+)(?:\s+(\S.*))?/)
			or die "Invalid line in index file: [$_]";

		$expired = $expired ? 1 : 0;
		if ($code =~ /watch\?v=([\w-]+)/)
		{
			$code = $1;
		}

		push(@clips, {
			expired	=> $expired,
			code 	=> $code,
			title 	=> $title,
		});
	}

	foreach my $id  (0..$#clips)
	{
		for (my $n = $id - 1; $n >= 0; $n--)
		{
			if (!$clips[$n]{expired})
			{
				$clips[$id]{previous} = $n;
				last;
			}
		}
		for (my $n = $id + 1; $n < @clips; $n++)
		{
			if (!$clips[$n]{expired})
			{
				$clips[$id]{next} = $n;
				last;
			}
		}
	}

	return @clips;
}
